package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!````P"5```````!``````````$BQ````
M`````````$``.``-`$``&P`:``8````$````0`````````!``$```````$``
M0```````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#0```````&`-````````<`````````!P``````````0`````````!````
M!`````````````````!``````````$```````'`8````````<!@`````````
M$`````````$````%`````"``````````($`````````@0```````'3T`````
M```=/0`````````0`````````0````0`````8`````````!@0````````&!`
M``````"X1P```````+A'`````````!`````````!````!@```/BK````````
M^+M```````#XNT```````"D$````````H`0`````````$`````````(````&
M````"*P````````(O$````````B\0`````````(``````````@````````@`
M````````!`````0````X`P```````#@#0```````.`-````````@````````
M`"``````````"``````````$````!````%@#````````6`-```````!8`T``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`T```````#@#0```````(``````````@``````````@`````````4.5T9`0`
M``#@H````````."@0```````X*!```````#\`````````/P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````^*L```````#XNT```````/B[0```
M````"`0````````(!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````$`````4```!'3E4``H``P`0````!````````
M``0````4`````P```$=.50!>LW(:.E5>8FL<$Q^XRWQ?EV%ZO@0````0````
M`0```$=.50```````P````(``````````````!$````Z````!`````@````@
M'!``!4`$AB@"``2`A@&,PHD`(DD@!`J8@C!!N@`""CH````[````/@```$$`
M``!"````2@```$P```!.````40```%(```!3````5````%8```!7````60``
M````````````>_!*:V[%WQ_.WD<M:W^:?"[%F[;49-1\(?_D#MEQ6!SB1\8!
ML@&+;ZQ+X\!"^M>'PN4_++KCDGSZH6Q@F4_#FVH)0]:'^9R!9J_,9L6YG$`X
M\HL<0D75[(D'<-/)U;)Q,V+;[16,)<P,.I<+I]VC:W^IG)O@IP(*:QJ>4`J*
M$%>CX/M)````````````````````````````````7`(``!(`````````````
M````````````PP$``!(`````````````````````````0P(``!(`````````
M````````````````^0```!(`````````````````````````G@$``!(`````
M`````````````````````0```"``````````````````````````9P$``!(`
M````````````````````````(@```!(`````````````````````````=`$`
M`!(`````````````````````````3P```!(`````````````````````````
M/`(``!(`````````````````````````C@(``!(`````````````````````
M````LP$``!(`````````````````````````C0```!(`````````````````
M````````G0```!(`````````````````````````ZP```!(`````````````
M````````````'P$``!(`````````````````````````,0,``!(`````````
M````````````````=`(``!(`````````````````````````80(``!(`````
M````````````````````>````!(`````````````````````````6````!(`
M````````````````````````9@```!(`````````````````````````6`$`
M`!(`````````````````````````9@(``!(`````````````````````````
MLP```!8`````````````````````````T0```!(`````````````````````
M````?P(``!(`````````````````````````20$``!(`````````````````
M````````K`$``!(`````````````````````````@`$``!(`````````````
M``````````````$``!(`````````````````````````X@```!(`````````
M````````````````#P$``!(`````````````````````````+0$``!(`````
M````````````````````3@(``!(`````````````````````````C0$``!(`
M````````````````````````-`$``!(`````````````````````````Y`$`
M`!(`````````````````````````-````!(`````````````````````````
M0@$``!(`````````````````````````.P$``!(`````````````````````
M````5P```!(`````````````````````````>0$``!(`````````````````
M````````SP$``!(`````````````````````````,`(``!(`````````````
M````````````;`$``!(`````````````````````````E````!(`````````
M````````````````?P```!(`````````````````````````7P```!(`````
M````````````````````%P$``!(`````````````````````````Q@```!(`
M````````````````````````\`$``!(`````````````````````````$```
M`!(`````````````````````````)@$``!(`````````````````````````
M;@```!(`````````````````````````AP$``!(`````````````````````
M````HP```!(```#`(4``````````````````.@,``!(`#@#P5T```````,0`
M````````CP,``!(`#@!@3T```````(X&````````'0```!(`#@#`(T``````
M`/0!````````L0(``!(`#@`@1$````````4`````````SP(``!(`#@#P54``
M`````/X!````````M0,``!(`#@`P1$```````/\!````````=0,``!``&``A
MP$``````````````````P@(``!(`#@`P1D```````"(`````````Y0(``!(`
M#@#P2T```````&$`````````1@,``!$`$```8$````````0`````````8@,`
M`!(`#@`064```````)\!````````;0,``!(`#@!`0T```````!\`````````
MB@,``!``&`"8P$``````````````````HP,``!(`#@!@3D`````````!````
M````S`,``!(`#@!@3$```````+(`````````50,``!``%P``P$``````````
M````````$@(``!(```#0(4``````````````````"0,``!(`#@!@1D``````
M`#$!````````10```!$`&`!`P$````````@`````````40$``!$`&`!@P$``
M``````@`````````G`,``!``%P`AP$``````````````````P@,``!$`%P`0
MP$````````@`````````_P$``!(```"`($``````````````````6P,``!(`
M#@#`)4```````"8`````````@0,``!(`#@#`6$```````$4`````````5P,`
M`"``%P``P$``````````````````1P```"$`&`!`P$````````@`````````
M'P,``!(`#@!`3D```````!T`````````\P(``!(`#@!@0T```````+,`````
M````%0,``!(`#@"P6D```````$L"````````(P(``!$`&`!PP$````````$`
M````````U`,``!(`#@"@1T```````$8$`````````%]?9VUO;E]S=&%R=%]?
M`%]?;&EB8U]S=&%R=%]M86EN`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?
M8VAK7V9A:6P`7U]E;G9I<F]N`'-T<FYC;7``;'-T870V-`!A8V-E<W,`;W!E
M;F1I<@!R96%D9&ER-C0`<W1R;&5N`%]?<W!R:6YT9E]C:&L`=6YL:6YK`&-L
M;W-E9&ER`')M9&ER`&)O;W1?1'EN84QO861E<@!03%]C=7)R96YT7V-O;G1E
M>'0`4&5R;%]N97=84P!097)L7VYE=UA37V9L86=S`')E861L:6YK`%!E<FQ?
M<W9?<V5T<'8`;65M8VAR`%!E<FQ?<W9?<V5T<'9N`&UE;6UO=F4`<F5A;&QO
M8P!G971P:60`;65M8W!Y`'-T<F-H<@!S=')D=7``<W1R=&]K`'-T<F-M<`!S
M=')R8VAR`'-T9&5R<@!?7W9F<')I;G1F7V-H:P!E>&ET`&QS965K-C0`<F5A
M9`!G971U:60`<W1R<W1R`&UK9&ER`%]?97)R;F]?;&]C871I;VX`7U]F<')I
M;G1F7V-H:P!O<&5N-C0`4&5R;%]G=E]F971C:'!V`%!E<FQ?9V5T7W-V`%!E
M<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?;6=?<V5T`%!E<FQ?<WES7VEN:70S
M`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7V%T9F]R:U]L;V-K`%!,7V1O7W5N
M9'5M<`!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]P87)S90!P97)L7V1E<W1R
M=6-T`'!E<FQ?9G)E90!097)L7W-Y<U]T97)M`'!E<FQ?86QL;V,`<&5R;%]C
M;VYS=')U8W0`<&5R;%]R=6X`;&EB<&5R;"YS;RXU+C,V`&QI8F,N<V\N-@!P
M87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%2
M7T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R
M7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!S:&%?
M=7!D871E`'AS7VEN:70`7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?
M;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O
M9P!M>5]P87)?<&P`<&%R7V1I90!P87)?:6YI=%]E;G8`1TQ)0D-?,BXQ-`!'
M3$E"0U\R+C,T`$=,24)#7S(N-`!'3$E"0U\R+C,S`$=,24)#7S(N,RXR`$=,
M24)#7S(N,RXT`$=,24)#7S(N,BXU`````0`!``$``@`#``$``@`$``(``@`"
M``$``0`"``(``0`"``(``0`"``(`!0`"``,``0`!``$``0`"``(``@`!``(`
M`@`"``$``@`"``$`!@`"``(`!0`"``$``0`"``(``P`"``(``0`!``<`"``"
M``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`"``(`
M`0`!``$``0`!``$``@`!``$``0`!``$````!``<`IP(``!``````````E)&6
M!@``"`#A`P``$````+21E@8```<`[`,``!`````4:6D-```&`/<#```0````
MLY&6!@``!0`!!```$````'(9:0D```0`#`0``!````!T&6D)```#`!@$```0
M````=1II"0```@`D!````````.B_0```````!@````8``````````````/"_
M0```````$@```!H``````````````/B_0```````!@```#8`````````````
M`$#`0```````!0```$T``````````````&#`0```````!0```$X`````````
M`````'#`0```````!0```%D``````````````""^0```````!P````$`````
M`````````"B^0```````!P````(``````````````#"^0```````!P````,`
M`````````````#B^0```````!P````0``````````````$"^0```````!P``
M``4``````````````$B^0```````!P```%$``````````````%"^0```````
M!P````<``````````````%B^0```````!P````@``````````````&"^0```
M````!P````D``````````````&B^0```````!P````H``````````````'"^
M0```````!P````L``````````````'B^0```````!P````P`````````````
M`("^0```````!P````T``````````````(B^0```````!P````X`````````
M`````)"^0```````!P````\``````````````)B^0```````!P```!``````
M`````````*"^0```````!P```!$``````````````*B^0```````!P```!(`
M`````````````+"^0```````!P```!,``````````````+B^0```````!P``
M`!0``````````````,"^0```````!P```!4``````````````,B^0```````
M!P```!8``````````````-"^0```````!P```!<``````````````-B^0```
M````!P```!@``````````````."^0```````!P```!D``````````````.B^
M0```````!P```#H``````````````/"^0```````!P```$L`````````````
M`/B^0```````!P```!L```````````````"_0```````!P```!P`````````
M``````B_0```````!P```!T``````````````!"_0```````!P```!X`````
M`````````!B_0```````!P```!\``````````````""_0```````!P```"``
M`````````````"B_0```````!P```"$``````````````#"_0```````!P``
M`"(``````````````#B_0```````!P```",``````````````$"_0```````
M!P```"0``````````````$B_0```````!P```"4``````````````%"_0```
M````!P```"8``````````````%B_0```````!P```"<``````````````&"_
M0```````!P```"@``````````````&B_0```````!P```"D`````````````
M`'"_0```````!P```"H``````````````'B_0```````!P```"L`````````
M`````("_0```````!P```"P``````````````(B_0```````!P```"T`````
M`````````)"_0```````!P```"X``````````````)B_0```````!P```"\`
M`````````````*"_0```````!P```#```````````````*B_0```````!P``
M`#$``````````````+"_0```````!P```#(``````````````+B_0```````
M!P```#,``````````````,"_0```````!P```#0``````````````,B_0```
M````!P```#4``````````````-"_0```````!P```#<``````````````-B_
M0```````!P```#@``````````````."_0```````!P```#D`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!=F?``!(A<!T`O_02(/$",,``````/\UZIT``/\E[)T`
M``\?0`#_)>J=``!H`````.G@_____R7BG0``:`$```#IT/____\EVIT``&@"
M````Z<#_____)=*=``!H`P```.FP_____R7*G0``:`0```#IH/____\EPIT`
M`&@%````Z9#_____);J=``!H!@```.F`_____R6RG0``:`<```#I</____\E
MJIT``&@(````Z6#_____):*=``!H"0```.E0_____R6:G0``:`H```#I0/__
M__\EDIT``&@+````Z3#_____)8J=``!H#````.D@_____R6"G0``:`T```#I
M$/____\E>IT``&@.````Z0#_____)7*=``!H#P```.GP_O___R5JG0``:!``
M``#IX/[___\E8IT``&@1````Z=#^____)5J=``!H$@```.G`_O___R52G0``
M:!,```#IL/[___\E2IT``&@4````Z:#^____)4*=``!H%0```.F0_O___R4Z
MG0``:!8```#I@/[___\E,IT``&@7````Z7#^____)2J=``!H&````.E@_O__
M_R4BG0``:!D```#I4/[___\E&IT``&@:````Z4#^____)1*=``!H&P```.DP
M_O___R4*G0``:!P```#I(/[___\E`IT``&@=````Z1#^____)?J<``!H'@``
M`.D`_O___R7RG```:!\```#I\/W___\EZIP``&@@````Z>#]____)>*<``!H
M(0```.G0_?___R7:G```:"(```#IP/W___\ETIP``&@C````Z;#]____)<J<
M``!H)````.F@_?___R7"G```:"4```#ID/W___\ENIP``&@F````Z8#]____
M);*<``!H)P```.EP_?___R6JG```:"@```#I8/W___\EHIP``&@I````Z5#]
M____)9J<``!H*@```.E`_?___R62G```:"L```#I,/W___\EBIP``&@L````
MZ2#]____)8*<``!H+0```.D0_?___R5ZG```:"X```#I`/W___\E<IP``&@O
M````Z?#\____)6J<``!H,````.G@_/___R5BG```:#$```#IT/S___\E6IP`
M`&@R````Z<#\____)5*<``!H,P```.FP_/___R5*G```:#0```#IH/S___\E
M0IP``&@U````Z9#\____)3J<``!H-@```.F`_/___R4RG```:#<```#I</S_
M__\E*IP``&@X````Z6#\__]32(/L,(E\)!Q(C7PD'$B)="002(UT)!!(B50D
M"$B-5"0(9$B+!"4H````2(E$)"@QP.B)____NH`@0`"_T"%``$B)UNCW.```
M@#U@G`````^$"@$``$B+!=.;``!D2(L`@(@J!````XM$)!R->`2-6`-(8_](
MP><#Z-+^__](BWPD$$2+1"0<2(G!2(D%/IP``$B+!TC'00CE84``2,=!&.AA
M0`!(B0%(BP6AFP``2(E!$$&#^`$/CAX!``!(@\<(08/``[H$````9@\?1```
M2(L'2&/R@\(!2(/'"$B)!/%$.<)UZDACTDB+/=";``!%,<"^\#]``$C'!-$`
M````B=KHB?O__X7`#X2!````2(L]JIL``.B5_?__2(UT)"2_HV!``(G#,<#H
M,A@``$B%P'1N2(L]AIL``.@Q^___Z*S\__](BT0D*&1(*P0E*`````^%EP``
M`$B#Q#")V%O#Z"O\__](B054FP``2(G'2(7`=''HM_S__TB+!;":``!D2(L0
MQH+7"0```.G-_O__2(L]*9L``.B$^___Z6[___](BST@FP``2(7_=`KH?C(`
M`.E\____OUA@0`!(C70D).B:%P``2(D%^YH``$B)QTB%P`^$6O___^O2N@0`
M``#I`?___[\!````Z.'Z___H_/S__V8N#Q^$``````!FD/,/'OHQ[4F)T5Y(
MB>)(@^3P4%1%,<`QR4C'Q\`C0`#_%1.:``#T9BX/'X0``````/,/'OK#9BX/
M'X0``````)"X*,!``$@]*,!``'03N`````!(A<!T";\HP$``_^!FD,-F9BX/
M'X0```````\?0`"^*,!``$B![BC`0`!(B?!(P>X_2,'X`T@!QDC1_G01N```
M``!(A<!T![\HP$``_^##9F8N#Q^$```````/'T``\P\>^H`]]ID```!U$U5(
MB>7H>O___\8%Y)D```%=PY##9F8N#Q^$```````/'T``\P\>^NN*9BX/'X0`
M`````$%72(G^3(U'.$%6055!5%532('LF`(``&1(BP0E*````$B)A"2(`@``
M,<!,C8PD@````$B)YV8N#Q^$``````!!BP!)BPA(@\<028/`"`_(B<!(B<I(
MB4?P2(G(2,'J($C!Z"A(P>DX)0#_``!("<A(B=%(P>((2,'A&('B``#_`(G)
M2`G(2`G02(E'^$PYSW6N9@]O1"009@]O7"0@2(U$)&A(C90D:`(``&8/;U0D
M,&8/;RT7>0``#Q^``````/,/;PAF#V_B9@]O4-A(@\`09@_O0(AF#^_*9@_O
MP68/;\AF#W/0'V8/<_$!9@_KP68/V\4/*4`(9@]OPV8/;]Q(.=!UNTR+#DR+
M7A!(BWX@2(M>&$R)R$R)RDB+;@A(BTPD"$C!ZAM(P>`%2`G0`P0D2(V,"YEY
M@EJ-E#B9>8):3(G82#'82"'H2#'8C3P"2(GJ2(GH2,'H`DC!XAY)B?I("<),
MB=A)P>H;08G03#'`3"'(3#'82`'(2(GY2,'A!4P)T4R+5"001(TD"$R)R$R)
MR4C!Z0)(P>`>3XV4$YEY@EI-B>5("<A)P>T;2#'"B<%((?I,,<),`=)-B>))
MP>(%30GJ3(ML)!A!`=)(B?I(P>\"2,'B'D6)TD^-A"B9>8):2`GZ38G52#'0
MB==,(>!)P>T;2#'(3`'`38G02<'@!4T)Z$R+;"0@00'`3(G@2<'L`DC!X!Y%
MB<!*C8PIF7F"6DP)X$V)Q4@QPDG![1M!B<1,(=)(,?I(`<I,B<%(P>$%3`GI
M3(ML)"@!T4R)TDG!Z@)(P>(>B<E*C;POF7F"6DP)TDF)S4@QT$G![1M!B=),
M(<!,,>!(`?A(B<](P><%3`GO3(ML)#`!QTR)P$G!Z`)(P>`>B?]/C:0LF7F"
M6DP)P$F)_4@QPDG![1M!B<!((<I,,=),`>))B?Q)P>0%30GL3(ML)#A!`=1(
MB<I(P>D"2,'B'D6)Y$^-E"J9>8):2`G*38GE2#'02<'M&XG12"'X3#'`3`'0
M38GB2<'B!4T)ZDR+;"1`00'"2(GX2,'O`DC!X!Y%B=)/C80HF7F"6D@)^$V)
MU4@QPDG![1N)QTPAXD@QRDP!PDV)T$G!X`5-">A,BVPD2$$!T$R)XDG![`)(
MP>(>18G`2HV,*9EY@EI,">)-B<5(,=!)P>T;08G43"'02#'X2`'(3(G!2,'A
M!4P)Z4R+;"10`<%,B=!)P>H"2,'@'HG)2HV\+YEY@EI,"=!)B<U(,<))P>T;
M08G"3"'"3#'B2`'Z2(G/2,'G!4P)[TR+;"18`==,B<))P>@"2,'B'HG_3XVD
M+)EY@EI,"<))B?U(,=!)P>T;08G02"'(3#'03`'@28G\2<'D!4T)[$R+;"1@
M00'$2(G(2,'@'DC!Z0)%B>1/C90JF7F"6D@)R$V)Y4@QPDG![1N)P4@A^DPQ
MPDP!TDV)XDG!X@5-">I,BVPD:$$!TDB)^DC![P)(P>(>18G23XV$*)EY@EI(
M"?I-B=5(,=!)P>T;B==,(>!(,<A,`<!-B=!)P>`%30GH3(ML)'!!`<!,B>!)
MP>P"2,'@'D6)P$J-C"F9>8):3`G@38G%2#'"2<'M&T&)Q$PATD@Q^D@!RDR)
MP4C!X05,">E,BVPD>`'13(G22,'B'DG!Z@*)R4J-O"^9>8):3`G228G-2#'0
M2<'M&T&)TDPAP$PQX$@!^$B)STC!YP5,">],BZPD@`````''3(G`2<'H`DC!
MX!Z)_T^-I"R9>8):3`G`28G]2#'"2<'M&T&)P$@ARDPQTDP!XDF)_$G!Y`5-
M">Q&C2PB2(G*2,'I`DR+I"2(````2,'B'D@)RD^-E"*9>8):38GL2#'02<'L
M&XG12"'X3#'`3`'038GJ2<'B!4T)XDR+I"20````00'"2(GX2,'@'DC![P)%
MB=)/C80@F7F"6D@)^$V)U$@QPDG![!N)QTPAZD@QRDP!PDV)T$G!X`5-">!%
MB<!,`<)-B>A)P>T"2<'@'D&)U$T)Z$R+K"28````3#'`3"'02HV,*9EY@EI-
MB>5(,?A)P>T;2`'(3(GA2,'A!4P)Z8G)2`'(3(G12<'J`DC!X1Y!B<5,"=%-
MB<)%B<!),<I$,=),BY0DH````$J-O!>AZ]EN38GJ2`'73(GJ2<'J&TC!X@5,
M"=*)TD@!UTR)XDC!XAY)P>P"08GZ3`.$)*@```!,">))B<R)R4@#C"2P````
M23'41#'@38VD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$3(GH2<'M`DC!
MX!Y%B>!,">A)B=6)TD@#E"2X````23'%1#'O3(VL.:'KV6Y,B<%,B<=(P>\;
M2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$DQRD4QXDZ-I!*A
MZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"28G(
M2`.$),````")R4DQT$@#C"3(````13'H3HVL`*'KV6Y,B=!-B=!)P>@;2,'@
M!4P)P(G`20'%2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"30````2#''1#'G
M3(VD.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$B>=,
M"=%)B<*)P$@#A"38````23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B!4P)
MTHG220'53(G"2<'H`DC!XAY%B>I,"<))B<B)R4DQT$@#C"3@````13'@3HVD
M`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$2(GX2,'O`DC!X!Y%B>!("?A(
MB=>)TD@#E"3H````2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)
M20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$@#A"3P````23'*13'B3HVD$J'K
MV6Y(B?I)B?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<B)
MR4DQT$4QZ$Z-K`"AZ]EN3(G038G02,'@!4G!Z!M(`XPD^````$P)P(G`20'%
M2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"0``0``2#''1#'G3(VD.:'KV6Y,
MB<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$B>=,"=%)B<*)P$@#
MA"0(`0``23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'53(G"
M2<'H`DC!XAY%B>I,"<))B<B)R4DQT$4QX$Z-I`"AZ]EN3(G038G02<'H&TC!
MX`5,"<!(`XPD$`$``(G`20'$2(GX2,'O`DC!X!Y%B>!("?A(B=>)TD@#E"08
M`0``2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G12<'J
M`DC!X1Y$B>],"=%)B<*)P$@#A"0@`0``23'*13'B3HVD$J'KV6Y(B?I)B?I)
MP>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<B)R4DQT$4QZ$Z-
MK`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q4B)^$C!X!Y(P>\"18GH2`.,
M)"@!``!("?A(B=>)TD@#E"0P`0``2#''1#'G38G$2(V,.:'KV6Y,B<=)P>P;
M2,'G!4P)YTV)U$G!Z@))P>0>B?]-"=1)B<)(`?F)P$TQXHG/2`.$)#@!``!%
M,>I)B?U.C902H>O9;DB)^DG![1M(P>(%3`GJ00'23(G"2<'H`DC!XAY%B=),
M"<)-B>!%B>1),=!)B=9!B=5$,<%-B=!(C8P(H>O9;DR)T$G!Z!M(P>`%3`G`
M1(T$`4B)^4C![P*XW+P;CTC!X1Y("?E)"<Z)ST@A^DTAUDD)UDB+E"1``0``
M2`'"3`'B38G$3`'R38G&2<'D!4G![AM-"?1!`=1,B=))P>H"2,'B'D6)Y$P)
MTD@)T4F)UD&)TDDA_DPAP4P)\4R+M"1(`0``20'&30'U38GF3`'I38GE2<'N
M&TG!Y05-"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPAPDP)
M\DR+M"10`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG![`)(
MP>(>B?],">)("=%)B=9!B=1-(<9,(>E,"?%,B[0D6`$``$D!QDT!\DF)_DP!
MT4F)^DG![AM)P>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)"<Y)
M(?Y,(>I,"?),B[0D8`$``$D!QDT!\$V)UDP!PDV)T$G!X`5)P>X;30GP00'0
M2(GZ2,'O`DC!XAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+M"1H`0``20'&
M30'T38G&3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)Y$P)
MT4&)RDD)SDTAQDPATDP)\DR+M"1P`0``20'&30'U38GF3`'J38GE2<'N&TG!
MY05-"?5!`=5,B<)(P>(>2<'H`D6)[4P)PD@)T4F)UD&)T$TAUDPAX4P)\4R+
MM"1X`0``20'&3`'W38GN2`'Y3(GO2<'N&TC!YP5,"?=)B=8!STR)X4G![`)(
MP>$>B?],">%!B<Q)"<Y-(>Y,(>),"?),B[0D@`$``$D!QDT!\DF)_DP!TDF)
M^DG![AM)P>(%30GR00'23(GJ2<'M`DC!XAY%B=),">I("=%)B=9!B=5((?E-
M(>9,"?%,B[0DB`$``$D!QDT!\$V)UDP!P4V)T$G![AM)P>`%30GP28G600'(
M2(GY2,'O`DC!X1Y%B<!("?F)STD)SDTAUD@A^DP)\DR+M"20`0``20'&30'T
M38G&3`'B38G$2<'N&TG!Y`5-"?1!`=1,B=))P>H"2,'B'D6)Y$P)TD@)T4F)
MUD&)TDDA_DPAP4P)\4R+M"28`0``20'&30'U38GF3`'I38GE2<'N&TG!Y05-
M"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPAPDP)\DR+M"2@
M`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG![`)(P>(>B?],
M">)("=%)B=9!B=1-(<9,(>E,"?%,B[0DJ`$``$D!QDT!\DF)_DP!T4F)^DG!
M[AM)P>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)"<Y)(?Y,(>I,
M"?),B[0DL`$``$D!QDT!\$V)UDP!PDV)T$G![AM)P>`%30GP00'02(GZ2,'O
M`DC!XAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+M"2X`0``20'&30'T38G&
M3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)Y$P)T4D)SD&)
MRDTAQDPATDP)\DR+M"3``0``20'&30'U38GF3`'J38GE2<'N&TG!Y05-"?5!
M`=5,B<))P>@"2,'B'D6)[4P)PD@)T4F)T$&)UTTAT$PAX4P)P4R+A"3(`0``
M20'`3`''38GH2`'Y3(GO2<'H&TC!YP5,"<=$C00Y3(GG2<'L`DB)T4C!YQY,
M">=!B?Q("?E,(>E,(>)("<I(BXPDT`$``$@!P4P!T4V)PD@#A"38`0``2`'*
M3(G!2<'J&TC!X05,"=&)R4@!RDR)Z4G![0)(P>$>08G23`GI2`G/28G-08G.
M3"''32'E20G]2HT\.$R)T$R+O"3X`0``3`'O38G52,'@!4G![1M,">B)P$@!
MQTR)P$G!Z`)(P>`>08G]20G`N-;!8LI,,<$QT4B+E"3@`0``2`'"3`'B38GL
M2`'*3(GI2<'L&TC!X05,">%-B=2)R4G!Y!Y(`<I)P>H"20''30GB38G$B=%%
MB<!-,=1$,>=,BZ0DZ`$``$D!Q$T!]$F)SDP!YTF)S$G![AM)P>0%30GT38GN
M2<'M`DG!YAY%B>1-"?5,B[0D\`$``$P!YT&)_$D!QDT!\$V)UDTQ[D0Q\DV)
MYDD!T$R)XDG![AM(P>(%3`GRB=))`=!(B<I(P>D"2,'B'D6)QD@)RD2)T4V)
MZDDQTDP!^4R+O"0``@``1#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,"=&)R4@!
MSTR)X4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD$`(``$4QZ$V)
MU4D!R$R)T4G![1M)`<=(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)\4R+
MM"0(`@``20'&3`'R38GF23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,"?*)TD@!
MUTR)TDG!Z@)(P>(>08G^20G21(GB28G,B<E,`?I-,=1,B[PD(`(``$4QX$V)
M]$D!T$R)\DG![!M)`<=(P>(%3`GBB=))`=!,B>I)P>T"2,'B'D6)Q$P)ZDR+
MK"08`@``20'%3`'I38G523'51#'O38GE2`'/3(GA2<'M&TC!X05,">F)R4@!
MSTR)\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD,`(``$4QT$V)
MZDD!R$R)Z4G!ZAM(P>$%3`G1B<E)`<A,B>%(P>$>2<'L`D6)PDD!QTP)X4R+
MI"0H`@``20'$3`'B38GT23',1#'G38G42`'73(G22<'L&TC!X@5,">*)TD@!
MUTR)ZDG![0)(P>(>08G\20G51(GR28G.B<E-,>Y,`?I,B[PD0`(``$4Q\$V)
MYDD!T$R)XDG![AM(P>(%3`GRB=))`=!,B=))P>H"2,'B'D6)QDP)TDR+E"0X
M`@``20'"3`'138GJ23'21#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,"=&)R4@!
MSTR)X4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD8`(``$4QZ$V)
MU4D!R$R)T4G![1M(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)\4R+M"1(
M`@``20'&3`'R38GF18GD23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,"?*)TD@!
MUTR)TDG!Z@)(P>(>08G^20G22(N4)%`"``!(`<))`=1(B<J)R4PQTDD!QT0Q
MPDV)\$D!U$R)\DG!Z!M(P>(%3`G"B=))`=1,B>I)P>T"2,'B'D6)X$P)ZDR+
MK"18`@``20'%3`'I38G523'51#'O38G%2`'/3(G!2<'M&TC!X05,">F)R4@!
MSTR)\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD<`(``$4QXDV)
M[$P!T4V)ZDG![!M)P>(%30GB38G$18G22<'D'DP!T4G!Z`))`<=-">!,BZ0D
M:`(``$&)RDD!Q$@#A"1X`@``3`'B38GT3`'(33'$1#'G38G42`'73(G22<'L
M&TC!X@5,">)-B>Q)P>T"2<'D'HG230GE18GT38G&2`'733'NB?I-`?Q%B<!$
M,?%)B=9,`<!-B>A,`>%)B=1)P>X;2<'D!4T)]$0!X4V)U$G!Z@))P>0>B<E-
M">)-,=!$,<=)B<A(`?A(B<](P><%2<'H&P'I00':3`G'1`-N($B)3@@!^$R)
M5AA(B09(B=!(P>H"2,'@'DR);B!("=!$`=A(B4802(N$)(@"``!D2"L$)2@`
M``!U$DB!Q)@"``!;74%<05U!7D%?P^B6Y?__9@\?1```05=!5D%505154TB#
M[`A(A?\/A+$```!,BS4"@P``387V#X2A````#[8'28G_28GUA,!T!#P]=5A%
M,>1)BQY(A=MT,TUCY$R)]0\?@`````!,B>),B?Y(B=_H0N/__X7`=0="@#PC
M/71'2(M="$B#Q0A(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```````28G\
M00^V1"0!28/$`83`=`0\/77N12G\ZY%F#Q]$``!,*?5*C5PC`4C!_0-!B6T`
MZ[1F#Q]$```QV^NJ#Q]``%-(B?M(@>R@````9$B+!"4H````2(F$))@````Q
MP$B)YNC*Y/__A<!U-HM4)!B!X@#P``"!^@!```!T"('Z`*```'4>O@(```!(
MB=_H#^7__X7`#Y3`#[;`ZP</'T0``#'`2(N4))@```!D2"L4)2@```!U"4B!
MQ*````!;P^@]Y/__9F8N#Q^$``````!FD$%505154TB![*@```!D2(L$)2@`
M``!(B80DF````#'`2(7_=`B`/P!(B?MU*TB+A"28````9$@K!"4H````#X4;
M`0``2('$J````%M=05Q!7<-F#Q]$``#HL^+__TF)Q$B%P'3(3(GGZ+/D__](
MA<`/A*H```"`>!,N2(UH$W40@'T!`'3?9BX/'X0``````(!X$RX/A)X```!(
MB=_H3N+__TB)[TF)Q>A#XO__08U\!0)(8__HEN'__TF)Z4F)V+D$8$``28G%
M2(G'O@$````QP$C'PO_____HXN/__TR)[TB)YN@7XO__3(GO@_C_=!"+1"08
M)0#P```]`$```'17Z'KA__],B>_HTN'__TR)Y^@*Y/__2(7`#X57____D$R)
MY^B(X___2(G?Z&#A___I^/[__P\?`(!]`2X/A5C___^`?0(`#X09____Z4G_
M__\/'X``````Z*/^___KI^C,XO__9F8N#Q^$``````"04[EPH$``NL`A0`"^
M"F!``$B+'>E_``!D2(L[Z&#C__]D2(L[13')6T&XPF%``+KP54``OB9@0`!,
MB<'IL.'__T%4NO\/``!52(GU4TB)^[\[8$``2('L$!```&1(BP0E*````$B)
MA"0($```,<!(B>;HVN'__X7`?A*)P8/H`4ACT(`\%`!U2(7`=3Q(BP5M?P``
M2(GJ2(G>9$B+..B.X/__2(N$)`@0``!D2"L$)2@```!U3DB!Q!`0``!;74%<
MPP\?@`````")P68/'T0``$QCX;XO````2(GG3(GBZ(W?__](A<!TI$B+!1%_
M``!,B>%(B>)(B=YD2(LXZ#_A___KG^BXX?__#Q^$``````!!5T%6055!5%5(
MB?532(G[2(/L&&1(BP0E*````$B)1"0(,<`QP(`^/0^4P$@!Q4B)[^@YX/__
M2(UT)`1(B=])B<0QP.C7^___2(7`#X0&`0``2(G'28G%Z!/@__],.>`/@](`
M``!,8W0D!$G!Y@,/M@.$P`^$G@$``#P]#X26`0``2(G8#Q\`#[90`4B#P`&$
MTG0%@/H]=>](*=A(F$R++9M^``!*C7P@`N@AW___30'U28E%`$B%P'162(L%
M?GX``$B-2P%*BQ0P#[8#B`*$P'0B/#UU#>L<#Q^``````(3`=!$/M@%(@\(!
M2(/!`8@"/#UUZ\8"/3'`9@\?1```#[9,!0"(3`(!2(/``83)=>](BT0D"&1(
M*P0E*`````^%!P$``$B#Q!A;74%<05U!7D%?PP\?0``QP&8/'T0```^V5`4`
M08A4!0!(@\`!A-)U[NN]#Q]``$R+/>%]``!)@S\`#X2V````3(GX13'MD$B#
MP`A$B>I!@\4!2(,X`'7OC7(#2&/V2,'F`XL%YWT``(7`=5O'!=E]```!````
M2(GWZ"G>__](A<`/A&'___]-8_5,B?Y(B<=)P>8#3(GRZ(O?__](B05T?0``
M2(G!08U%`42);"0$2)A(QP3!`````.F(_O__9@\?A```````3(G_Z&C@__](
MB05!?0``2(G!2(7`#X0&____36/U2<'F`^N[#Q]``#'`Z7_^__^^$````$4Q
M[>E?____Z'_?__]F9BX/'X0```````\?0`"Y<*!``+K`(4``O@I@0`!(BP6:
M?```9$B+..D1X/__D%-(@>P@(```9$B+!"4H````2(F$)!@@```QP.BPW?__
MN@$0``"^`0```$B-O"00$```08G`0;E&8$``,<"Y2F!``.B9W___N@`0``!(
MB>9(C;PD$!```.B$WO__A<!X3XUX`4B)PTAC_^@"W?__2(7`=#Q(8]M(B>9(
MB<=(B=KHK-___\8$&`!(B<%(BX0D&"```&1(*P0E*````'4,2('$("```$B)
MR%O#Z*'>__\QR>O89F8N#Q^$``````!FD.D[____9F8N#Q^$``````!!54%4
M28G\OUA@0`!54TB)\TB![+@0``!D2(L$)2@```!(B80DJ!```#'`2(UT)`SH
MN_C__[XO````3(GG2(G%Z.O=__](A<!T/C'`3(GFOV%@0`#H=_S__TR)X$B+
ME"2H$```9$@K%"4H````#X6'`0``2('$N!```%M=05Q!7<,/'X``````2(G?
MZ-#=__^^;F!``$B)Q^@#WO__2(G#2(7`=*6`.P`/A-T```!FD$B%[7032(G>
M2(GOZ-#=__^%P`^$H@```$B)W^APW/__2(U4`_])B<5(.=-R#^L=D,8"`$B#
MZ@%(.=-T!8`Z+W3O2(G?Z$?<__])B<5,B>?H/-S__TF-1`4!2#W_#P``#X<U
M____2(/L"+ER84``N@`0```QP$%40;EP8$``28G8O@$```!(C;PDL````.C.
MW?__2(UT)"!(C;PDL````.C\V___6EF%P'40BT0D*"4`\```/0"```!T5KYN
M8$``,?_H*MW__TB)PTB%P`^$R/[__X`[``^%)?___TB%[70&@'T`+G0:0;T!
M````NU9@0`#I5O___V8N#Q^$``````"`?0$`=+3KW@\?A```````O@$```!(
MC;PDH````.A.W?__A<!UE$B-M"2@````OV%@0`#HZ/K__TB-O"2@````Z&O<
M___I8O[__^B!W/__D%.^+P```$B)^^C"V___2(U0`4B%P$@/1=I(B=];Z3[<
M__]F9BX/'X0```````\?`%532('L&!```&1(BP0E*````$B)A"0($```,<!(
MA?\/A,L```"`/P!(B?L/A+\```#HVMK__TB-4`%(@?H`$```#X?A````2(GE
M2(GO@_H(<@Z)T4B)WL'I`_-(I4B)\S')]L($=`F+"XD/N00```#VP@)T#D0/
MMP0+9D2)!`](@\$"@^(!=`</MA0+B!0/2(U$!?](.<5R$^L6#Q]$``#&``!(
M@^@!2#GH=`6`."]T[[XO````2(GOZ.+:__](A<!T+4@YQ7)82(GOZ&#;__](
MBY0D"!```&1(*Q0E*````'5)2('$&!```%M=PP\?`$B+A"0($```9$@K!"4H
M````=2E(@<08$```OU9@0`!;7>D:V___9BX/'X0``````,8``.NC#Q\`,<#K
MI.@?V___9F8N#Q^$```````/'T``2(/L&&1(BP0E*````$B)1"0(,<`/'T``
M,<!(C70D!+]R8$``Z%?U__](A<!T.DAC5"0$2(L%9G@``$B-!-!(BU`(2(D0
M2(72=,YF#Q]$``!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$```QP$B-="0$OWM@
M0`#H!_7__TB%P'0Z2&-4)`1(BP46>```2(T$T$B+4`A(B1!(A=)TSF8/'T0`
M`$B+4!!(@\`(2(D02(72=?#KMF8/'T0``#'`2(UT)`2_@V!``.BW]/__2(7`
M=#I(8U0D!$B+!<9W``!(C0302(M0"$B)$$B%TG3.9@\?1```2(M0$$B#P`A(
MB1!(A=)U\.NV9@\?1```,<!(C70D!+^,8$``Z&?T__](A<!T.DAC5"0$2(L%
M=G<``$B-!-!(BU`(2(D02(72=,YF#Q]$``!(BU`02(/`"$B)$$B%TG7PZ[9F
M#Q]$```QP$B-="0$OY-@0`#H%_3__TB%P'0Z2&-4)`1(BP4F=P``2(T$T$B+
M4`A(B1!(A=)TSF8/'T0``$B+4!!(@\`(2(D02(72=?#KMF8/'T0``#'`2(UT
M)`2_HV!``.C'\___2(7`=#I(8U0D!$B+!=9V``!(C0302(M0"$B)$$B%TG3.
M9@\?1```2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```,<!(C70D!+]88$``Z'?S
M__](A<!T.DAC5"0$2(L%AG8``$B-!-!(BU`(2(D02(72=,YF#Q]$``!(BU`0
M2(/`"$B)$$B%TG7PZ[9F#Q]$```QP$B-="0$OZ]@0`#H)_/__TB%P'0Z2&-4
M)`1(BP4V=@``2(T$T$B+4`A(B1!(A=)TSF8/'T0``$B+4!!(@\`(2(D02(72
M=?#KMF8/'T0``#'`2(UT)`2_N6!``.C7\O__2(7`=#I(8U0D!$B+!>9U``!(
MC0302(M0"$B)$$B%TG3.9@\?1```2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```
M,<!(C70D!+_#8$``Z(?R__](A<!T.DAC5"0$2(L%EG4``$B-!-!(BU`(2(D0
M2(72=,YF#Q]$``!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$```QP$B-="0$OV%@
M0`#H-_+__TB%P'0Z2&-4)`1(BP5&=0``2(T$T$B+4`A(B1!(A=)TSF8/'T0`
M`$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B-="0$O\U@0`#HZ?'__TB%P'0/
M2(G&O[E@0``QP.BU]?__,<!(C70D!+_>8$``Z,3Q__](A<!T#TB)QK_P8$``
M,<#HD/7__TB-="0$O_M@0``QP.B?\?__2(G&2(7`=#&_6&!``#'`Z&OU__](
MBT0D"&1(*P0E*````'4\ON-A0`"_DV!``#'`2(/$&.E&]?__,<!(C70D!+\+
M84``Z%7Q__](A<!TQ4B)QK^O8$``,<#H(?7__^NTZ,K6__]F+@\?A```````
M2(/L&+^O8$``9$B+!"4H````2(E$)`@QP$B-="0$Z`WQ__](A<!T,`^V$(#Z
M,`^4P(32#Y3""="#\`$/ML!(BU0D"&1(*Q0E*````'4.2(/$&,,/'T0``#'`
MZ^+H7];__V9F+@\?A```````#Q]``$B![-@```!(B70D*$B)5"0P2(E,)#A,
MB40D0$R)3"1(A,!T-P\I1"10#RE,)&`/*50D<`\IG"2`````#RFD))`````/
M*:PDH`````\IM"2P````#RF\),````!D2(L$)2@```!(B40D&#'`2(GZ2(V$
M).````!(B>%(BSV`<P``2(E$)`B^`0```$B-1"0@QP0D"````,=$)`0P````
M2(E$)!#HF-3__[__````Z'[3__]F9BX/'X0```````\?`$%4N@(````Q]D&)
M_%532('L$``!`&1(BP0E*````$B)A"0(``$`,<!(B>/HT-7__TB-:/](B>I(
MP?H_2,'J,$B-1!4`#[?`2"G02"G%#XBA````#Q]$```QTDB)[D2)Y^B;U?__
M2(/X_P^$F@```+H(``$`2(G>1(GGZ!'3__^#^/]T>4B82(/X!W942(U$`_A(
M.=AS$^M(#Q^$``````!(@^@!2#G8<C=(BPU(<@``2#D(=>M(*=A(`>A(BY0D
M"``!`&1(*Q0E*````'5'2('$$``!`%M=05S#9@\?1```2('M```!`$B!_0``
M__\/A63___](Q\#_____Z[Z_*6%``#'`Z#?^__^_'&%``#'`Z"O^___H=M3_
M_V8/'T0``$B#[`CHI]3__XG'Z/#2__](A<!T`TB+`$B#Q`C##Q\`05152(G]
MOS5A0`!32(/L$&1(BP0E*````$B)1"0(,<!(C70D!.B6[O__2(7`=`B`.`!(
MB<-U,4B+1"0(9$@K!"4H````#X6P````2(GN2(/$$+\U84``,<!;74%<Z3[R
M__]F#Q]$``!(B>Y(B<?H3=/__TB%P'0@2(M$)`AD2"L$)2@```!U<TB#Q!!;
M74%<PP\?@`````!(B>_H<-+__TB)WTF)Q.AETO__28U\!`+HN]'__TB#[`A)
MB>BY<F%``%-(Q\+_____2(G'28G$0;EN8$``O@$````QP.C_T___6%I(BT0D
M"&1(*P0E*````'4(3(GFZ5/____H4-/__T%7059!54%454B)_;]88$``4TB!
M["@!``!D2(L$)2@```!(B80D&`$``+A,84``2(UT)`1(QT0D0`````!(QT0D
M>`````!(QT0D(`````!F2`]NP+CI8$``#Q8%`%$```\I1"0P9D@/;L"X!F%`
M``\6!?)0```/$40D6&9(#V[`N%UA0``/%@7D4```#Q%$)&AF2`]NP#'`#Q8%
MV5````\I1"00Z!?M__](A<!T#(`X`$B)PP^%1@0``.C1TO__B<?H&M'__TB%
MP`^$P0,``$B+&$B%VP^$M0,``$B)W^@MT?__2(U\``'H@]#__T0/M@-)B<5)
MB<1%A,!T-`\?0`!%#[;`3(GON6MA0``QP$C'PO____^^`0```$B#PP%)@\4"
MZ+G2__]$#[8#183`==!,C6PD6+_P8$``ZQ$/'T``28M]`$F#Q0A(A?]T.TB-
M="0$,<#H9^S__TB)PTB%P'3?@#@`=-I(B<?H(NW__X7`=,Y(B=_HMM'__TB)
MPTB%P'4^9@\?1```3(UL)#!)BUT`2(7;="J`.P`/A.$"``!(B=_HZ>S__X7`
M#X7Q````28M="$F#Q0A(A=MUV@\?0`!(B=_H2-#__TR)YTF)Q>@]T/__18VT
M!00$``!-8_9,B??HBL___T%428G80;EP8$``:'EA0`!(B<=)B<6Y<&%``$C'
MPO____^^`0```#'`Z,S1__],B>^^P`$``.@OTO__7T%8@_C_=1+H\M#__T2+
M"$&#^1$/A:$"``!(C;0D@````$R)[^@UT?__B<.%P'1O2(M-`$B+/:1N``!-
MB>@QP+HP8D``O@$```#HH,[__T4QY$B+A"08`0``9$@K!"4H````#X7S`P``
M2('$*`$``$R)X%M=05Q!74%>05_#D$B)WTF#Q0CHA-#__TB)PTB%P`^$U?[_
M_^D#____#Q\`BX0DF````"4`\```/0!````/A7K___]$BZ0DG````.BLT/__
M03G$#X5D____BX0DF````"7_`0``/<`!```/A4W___],B??H9,[__TB-="0$
MOT!A0`!)B<0QP.B@ZO__2(7`#X0W`@``2(M]`$B)QNB;\?__28G'2(7`#X0?
M`@``3(G_Z,?.__])B<:#^`-^-TB8OGYA0`!)C7P'_.C^S___A<!U(D&#_@0/
MA-0"``!!C4;[2)A!@#P'+P^$PP(```\?@``````QP$B-="0$OZ]@0`#H)^K_
M_TB%P`^$S@$```^V`(3`#X3#`0``/#`/A+L!``"^XV%``+^O8$``,<#HVNW_
M_^@%SO__:,)A0`!-B>A,B>=02,?"_____T&Y<&!``#'`N:)A0`"^`0```.CK
MS___6%KK3`\?@`````#H&\___X,X$75-Z,'-__^#PP%(@^P(38GH:,)A0`!!
MN7!@0`!,B>>YL&%``%-(Q\+_____O@$```!0,<#HG\___TB#Q""^P`$``$R)
MY^C^S___@_C_=*E,B>_HH<W__TR)YK]88$``,<#H,NW__TR)Y^B*^O__Z?C]
M__\/'T0``#';Z3G]__]F#Q^$``````!,C60D$.L-9@\?A```````28/$"$F+
M/"1(A?\/A(<````QP$B-="0$Z`/I__](A<!TWH`X`'392(G'Z&'.__](B<-(
MA<!TR>G_^___2(M-`$B+/1EL``!-B>@QP+KP84``O@$```#H%<S__^EP_?__
M2(G'Z/CY__](BX0D&`$``&1(*P0E*`````^%7@$``$B!Q"@!``!(B=];74%<
M05U!7D%?Z?C-__^_#0```+M%84``Z"G,__]!N%,```!)B<5)B<3IJ/O__P\?
MA```````3(M]`.G8_?__#Q^``````#'V3(G_,<#H-,W__XG%A<`/A"_^__^)
MQ^@S^/__28G&2(7`#X@<_O__,=)(C7#VB>_H&L[__[H&````2(UT)`J)[^B9
MR___2(/X!@^%P0```(%\)`H`0T%##X7F_?__9H%\)`Y(10^%V?W__S'228UV
MSHGOZ-?-__^Z*````$B-M"2`````B>_H4\O__TB#^"AU?[F384``O@$```!-
MB>A,B>?&A"2H`````$&Y<&!``$C'PO____]HPF%``$B-A"2(````4#'`Z*/-
M__]97ND3_O__2(MM"$B%[0^$-_W__TB)[^BWR___2(/X`P^&)?W__TB-?`7\
MOH-A0`#H[LS__X7`3`]$_>D+_?__Z,[,__^_B&%``#'`Z'+V__]FD%6_DV!`
M`%-(@^P82(L=[FD``&1(BP0E*````$B)1"0(,<!(C70D!&1(BRL/MH6P````
MB(6Q````,<#H\>;__TB%P'0)@#@Q#X13`0``,<#H7/'__V1(BRM(B>^Y`P``
M`+H!````OL%A0`#HD<K__TB)Q4B%P'0F2(M`$&1(BSNZPV%``$B+,.BDRO__
M2(M%$$B+,/9&#D`/A3,!``!D2(L[N0,```"Z`0```+[(84``Z$O*__](B<5(
MA<!T+4B-="0$OV%@0``QP.ABYO__2(G"2(7`#X36````2(M%$&1(BSM(BS#H
M1LK__V1(BSNZ`0```+[*84``Z%/)__]D2(L[NM]A0`!(B<;H(LK__V1(BP-(
MC70D!+]88$``QH"Q`````#'`Z`;F__](B05G:0``2(G#2(7`=#^^P`$``$B)
MW^AZS/__C5`!@_H!=@F#^!$/A8<```!(BT0D"&1(*P0E*`````^%C@```$B#
MQ!A;7<-F#Q]$``!(BSTA:0``Z.SW__](B04-:0``2(G#2(7`=::_B&)``#'`
MZ''+__^0@'@!``^$KO[__^F>_O__D$B+!>EH``!(BS!(BT402(LXZ'KH___I
M'____P\?1```9$B+.^C7RO__Z;_^__^)P4B+!;EH``!(B=J_L&)``$B+,#'`
MZ!?+___HPLK__V:055-(B?N_KV!``$B#[!AD2(L$)2@```!(B40D"#'`2(UT
M)`3H".7__TB%P'0<#[80A-(/E,"`^C`/E,((T'4*2(7;=`6`.P!U%TB+1"0(
M9$@K!"4H````=69(@\086UW#2(G?Z`CN__^^+P```$B)QTB)Q>B8R?__2(U0
M`4B%P$@/1>I(B>_H%<K__[H$````OGEA0`!(B<?H,\C__X7`=:A(BT0D"&1(
M*P0E*````'4.2(/$&$B)WUM=Z='E___H_,G__V9F+@\?A```````D$B#[`B_
M@````.@"R/__9@]O!;I'``!(QT`P``````\1`&8/;P6W1P``QT!X``````\1
M0!!F#V\%M$<```\10"!(@\0(PV9F+@\?A```````05=(8\)!5DF)QD%5051)
MB?Q52(UO.%-(B?-(@^P(2(MW*$B+5S"-#,9(.?%(B4\H2(/2`$C!Z!U(`=!(
MB4<P2&-'>(7`#X7M````08/^/P^.*P$``$&#[D!%B?=!P>\&18UO`4G!Y09)
M`=T/'T0``/,/;P-,B>=(@\-`#Q%%`/,/;TO0#Q%-$/,/;U/@#Q%5(/,/;UOP
M#Q%=,.@!S?__3#GK=<Q!P><&12G^26/&2(/X"')<28M5`$B-30A(@^'X28E4
M)#A)BU0%^$B)5`7X2"G-2`'H22GM2(/@^$B#^`AR&$B#X/@QTDF+=!4`2(DT
M$4B#P@A(.<)R[D6)="1X2(/$"%M=05Q!74%>05_#9I"H!'5T2(7`=.%!#[95
M`$&(5"0XJ`)TTT$/MU0%_F:)5`7^Z\8/'T``0;]`````2(U\!0!(B=Y!*<=%
M.?=%#T_^36/O3(GJZ"7)__]!BT0D>$0!^$&)1"1X@_A`=9),B>=%*?Y,`>OH
M)<S__^G+_O__28G=Z2/___]!BU4`08E4)#A!BU0%_(E4!?SI6____Y!!5DR-
M=CA!54%454B)_5-,BVXH2(GS3(MF,$R)Z$C!Z`.#X#^-2`%(F,9$!CB`2&/!
M3`'P@_DX#XZ#`0``OD`````ISG0/,=*)T8/"`<8$"``Y\G+S2(G?Z*/+__]F
M#^_`#Q%#.$G'1C``````00\11A!!#Q%&($R)XD$/ML5,B>],B>Y(P>H82,'@
M"$R)X4C![Q!)B=!,B>I(P>X8#[;60`^V_T`/MO9(P>D02`G03(GB#[;)2,'@
M"$@)^`^V_D$/MM!(P>`(2`GP00^V]$C!X`A("?!(P>`(2`GX2(G?2,'@"$@)
MR$C!X`A("=!(B4-PZ`K+__](BP-(B=](P>@8B$4`2(L#2,'H$(A%`4B+`XAE
M`DB+`XA%`TB+0PA(P>@8B$4$2(M#"$C!Z!"(105(BT,(B&4&2(M#"(A%!TB+
M0Q!(P>@8B$4(2(M#$$C!Z!"(10E(BT,0B&4*2(M#$(A%"TB+0QA(P>@8B$4,
M2(M#&$C!Z!"(10U(BT,8B&4.2(M#&(A%#TB+0R!(P>@8B$402(M#($C!Z!"(
M11%(BT,@B&422(M#((A%$UM=05Q!74%>Z?K$__]F+@\?A```````NC@````Q
M_RG*@_H(<D*)T4C'``````!(QT0(^`````!(C4@(2(/A^$@IR`'"@^+X@_H(
M#X)^_O__@^+X,<")QH/`"$B)/#$YT'+SZ6?^___VP@1U(X72#X1:_O__Q@``
M]L("#X1._O__,<EFB4P0_NE"_O__#Q\`QP``````QT00_`````#I+/[__P\?
M1```\P\>^DB+#?UB``#ID,/___,/'OI(@^P(2(/$",,`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!)
M;G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R]S96QF+V5X90`O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!L<V5E:R!F86EL960`<F5A9"!F86EL960`
M3$1?3$E"4D%265]0051(`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315(`
M55-%4DY!344`)3`R>``E<R5S)7,E<P!P87(M`'!A<FP`+G!A<@!S:&]R="!R
M96%D`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M
M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`V,0`M90`M
M+0```````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O(&-R96%T92!C86-H
M92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A
M8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````````
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D
M8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2
M+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*
M)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S
M7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*
M;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE
M(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@
M)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@
M;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@
M)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H
M*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?
M34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D
M8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R
M;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64[
M"G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P
M,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL
M(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI
M.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?
M<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S
M96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@
M>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO
M=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C
M(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA
M<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?
M1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD
M(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P
M;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A
M9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B
M7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C
M:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H
M92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,
M15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I
M.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T
M(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@
M+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?
M1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B
M+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B
M=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M
M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L
M;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@
M7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF
M+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M
M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U
M<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE
M?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII
M9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W
M*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#
M86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD
M9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T
M=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I
M;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@
M/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD
M(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA
M;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*
M;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II
M<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@
M*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@
M)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P
M87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N
M7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=
M(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%
M55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E
M:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=6
M6S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF
M("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G
M02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L
M92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G
M86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS
M:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE
M('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D
M,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD[
M"FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG
M4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O
M<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG
M('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII
M9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY
M;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>
M7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I]
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I
M<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#
M.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H
M+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H
M9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D
M;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D
M;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O
M=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R
M96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,
M;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!8
M6%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D[
M"FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS
M92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<
M421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q
M*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD
M?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C
M:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S
M92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT
M+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D
M;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7
M<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R
M:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]
M"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB
M*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T
M>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@
M/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X]
M(")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@
M)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L
M;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B
M.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F
M:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH
M*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@
M7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H
M:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@
M>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E
M>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I
M;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L
M<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H
M)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE
M(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"([
M"GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP
M87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O
M9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`
M05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D
M97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN
M*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H
M)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E
M<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q
M=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R
M:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@
M0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I
M<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER
M92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R
M97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@
M871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U
M:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![
M(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E
M<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@
M>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP
M9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U
M<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER
M.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD
M)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L
M96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E
M96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG
M=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H
M+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C
M86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@
M*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[
M4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C
M86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-
M4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`
M7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H
M+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B
M.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H
M<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L
M("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE
M+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D
M9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O
M*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*
M:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[
M4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA
M;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S
M>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA
M;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T
M=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?
M<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!
M4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S
M+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@
M+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?
M<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!
M345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@
M>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@
M)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I
M"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H
M*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<
M+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E
M;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E
M='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-
M4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[
M4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*
M:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP
M<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I
M9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP
M86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE
M.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@
M)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``$-!0TA%``!P97)L>'-I+F,`````
M````_____P````#_____``````$C16<`````B:O-[P````#^W+J8`````'94
M,A``````\.'2PP```````````````%9@0```````46%```````!984``````
M`&)A0````````1L#._P````>````0'___T`!``#@@O__]`4``."$__\8`0``
M$(7__RP!``#0A?__:`$``$"<__^X`0``$)W__P0"``"@G?__*`(``!"?__]D
M`@``4)___X`"```@H/__M`(``&"B__\``P``@*+__Q0#``!`H___.`,``%"C
M__],`P``4*7__YP#``"`I?__N`,``,"F___P`P``$*O__PP$``"`J___*`0`
M`$"L__]`!```8*W__W@$``"`K?__D`0``("N___@!```$+7__Y`%```0M___
MO`4``."W__\8!@``,+C__S`&``#0N?__?`8``""\___`!@```````!0`````
M`````7I2``%X$`$;#`<(D`$``!`````<````P(/__R8`````1`<0$````#``
M``#<@___!0`````````D````1````/A]__^@`P````X01@X82@\+=PB``#\:
M.RHS)"(`````3````&P```!@A/__:A8```!"#A"/`DD.&(X#0@X@C01"#BB,
M!4$.,(8&00XX@P='#M`%`T(6"@XX00XP00XH0@X@0@X80@X00@X(00L```!(
M````O````(":___,`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#
M!T0.0`)L"@XX1`XP00XH0@X@0@X80@X00@X(20L`(`````@!```$F___@P``
M``!!#A"#`DH.L`$"<0H.$$$."$$+.````"P!``!PF___9`$```!"#A"-`D(.
M&(P#00X@A@1!#BB#!4<.T`%^"@XH00X@00X80@X00@X(1PL`&````&@!``"D
MG/__0`````!!#A"#`F<."````#````"$`0``R)S__\@`````0@X0C`)&#AB&
M`T0.((,$3PZP(`)A"@X@00X800X00@X(2`M(````N`$``&2=__\Q`@```$(.
M$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9$#CB#!T<.4`,5`0H..$$.,$$.*$(.
M($(.&$(.$$(."$4+$`````0"``!8G___'P`````````@````&`(``&2?__^S
M`````$$.$(,"1PZP0`*="@X01`X(00L0````/`(```"@__\%`````````$P`
M``!0`@``_)____\!````0@X0C0)"#AB,`TD.((8$00XH@P5*#N`A`F(*#BA!
M#B!!#AA"#A!"#@A("P*1#N@A3@[P(6X.Z"%!#N`A````&````*`"``"LH?__
M(@````!!#A"#`EP."````#0```"\`@``P*'__S$!````00X0A@)!#AB#`T<.
ML"`"X0H.&$$.$$$."$0+6@H.&$8.$$$."$\+&````/0"``#(HO__1@0```!$
M#B`#$00*#@A%"Q@````0`P``_*;__V$`````1`X@`DX*#@A&"P`4````+`,`
M`%"G__^R`````$<.X`$````T````1`,``/BG__\:`0```$(.$(P"2PX8A@-!
M#B"#!$<.L(`$`L`*#B!!#AA!#A!"#@A'"P```!0```!\`P``X*C__QT`````
M1`X06`X(`$P```"4`P``Z*C__P`!````0@X0C`)!#AB&`TD.((,$1`XP`D(*
M#B!(#AA!#A!"#@A+"V0*#B!!#AA!#A!"#@A("V$..$D.0&`..$$.,```K```
M`.0#``"8J?__C@8```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&20XX@P='
M#N`"`\\!#N@"3@[P`FP.Z`)"#N`"`FT*#CA$#C!!#BA"#B!"#AA"#A!"#@A"
M"P,P`0[H`D<.\`)?#N@"00[@`E\.Z`)(#O`"3P[X`DT.@`-+#N`"`N$*#CA$
M#C!!#BA"#B!"#AA"#A!"#@A%"P+U#N@"20[P`D@.Z`)!#N`"```H````E`0`
M`'BO___^`0```$$.$(8"1@X8@P-$#C`#9`$*#AA!#A!!#@A'"S0```#`!```
M3+'__\0`````00X0A@)!#AB#`TP.,`)/"@X800X000X(00L"50H.&$0.$$$.
M"$4+(````/@$``#D?/__]`$```!!#A"#`D0.0`-7`0H.$$,."$$+%````!P%
M``#`L?__10````!$#A`"0`X(2````#0%``#XL?__GP$```!"#A"/`D4.&(X#
M10X@C01"#BB,!40.,(8&10XX@P='#D`"Y0H..$$.,$$.*$(.($(.&$(.$$(.
M"$,+`$````"`!0``3+/__TL"````0@X0C@)&#AB-`T(.((P$00XHA@5$#C"#
M!@.;`0H.*$$.($(.&$(.$$(."$\+````````$````,0%``!8M?__$```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````"@)D```````'`F0````````0````````"7`@``````
M``$`````````IP(````````,```````````@0```````#0`````````074``
M`````!D`````````^+M````````;``````````@`````````&@``````````
MO$```````!P`````````"`````````#U_O]O`````*`#0```````!0``````
M```@#4````````8`````````F`1````````*`````````#`$````````"P``
M```````8`````````!4````````````````````#``````````B^0```````
M`@````````!8!0```````!0`````````!P`````````7`````````!@30```
M````!P````````"($D````````@`````````D``````````)`````````!@`
M````````'@`````````(`````````/O__V\``````0````````#^__]O````
M``@20```````____;P`````!`````````/#__V\`````4!%`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```(O$`````````````````````````````V($```````$8@0```````5B!`
M``````!F($```````'8@0```````AB!```````"6($```````*8@0```````
MMB!```````#&($```````-8@0```````YB!```````#V($````````8A0```
M````%B%````````F(4```````#8A0```````1B%```````!6(4```````&8A
M0```````=B%```````"&(4```````)8A0```````IB%```````"V(4``````
M`,8A0```````UB%```````#F(4```````/8A0```````!B)````````6(D``
M`````"8B0```````-B)```````!&(D```````%8B0```````9B)```````!V
M(D```````(8B0```````EB)```````"F(D```````+8B0```````QB)`````
M``#6(D```````.8B0```````]B)````````&(T```````!8C0```````)B-`
M```````V(T```````$8C0```````5B-```````!F(T```````'8C0```````
MAB-```````"6(T```````*8C0```````MB-`````````````````````````
M````````````````````````````````````^&)````````*4$%2+G!M"@!'
M0T,Z("A/<&5N:WEL:6X@,3(N,RXP+3%O:S,I(#$R+C,N,```+G-H<W1R=&%B
M`"YI;G1E<G``+FYO=&4N9VYU+G!R;W!E<G1Y`"YN;W1E+F=N=2YB=6EL9"UI
M9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N
M=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`
M+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F
M<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD
M871A`"YB<W,`+F-O;6UE;G0`````````````````````````````````````
M``````````````````````````````````````````````````````````L`
M```!`````@`````````8`T```````!@#````````'```````````````````
M``$````````````````````3````!P````(`````````.`-````````X`P``
M`````"`````````````````````(````````````````````)@````<````"
M`````````%@#0```````6`,````````D````````````````````!```````
M`````````````#D````'`````@````````!\`T```````'P#````````(```
M``````````````````0```````````````````!'````]O__;P(`````````
MH`-```````"@`P```````/@`````````!@`````````(````````````````
M````40````L````"`````````)@$0```````F`0```````"("`````````<`
M```!````"``````````8`````````%D````#`````@`````````@#4``````
M`"`-````````,`0```````````````````$```````````````````!A````
M____;P(`````````4!%```````!0$0```````+8`````````!@`````````"
M``````````(`````````;@```/[__V\"``````````@20```````"!(`````
M``"```````````<````!````"````````````````````'T````$`````@``
M``````"($D```````(@2````````D``````````&``````````@`````````
M&`````````"'````!````$(`````````&!-````````8$P```````%@%````
M````!@```!8````(`````````!@`````````D0````$````&```````````@
M0````````"`````````;````````````````````!```````````````````
M`(P````!````!@`````````@($```````"`@````````H`,`````````````
M`````!``````````$`````````"7`````0````8`````````P"-```````#`
M(P```````%`Y```````````````````0````````````````````G0````$`
M```&`````````!!=0```````$%T````````-````````````````````!```
M`````````````````*,````!`````@``````````8$````````!@````````
MX$```````````````````!````````````````````"K`````0````(`````
M````X*!```````#@H````````/P````````````````````$````````````
M````````N0````$````"`````````."A0```````X*$```````#8!0``````
M````````````"````````````````````,,````.`````P````````#XNT``
M`````/BK````````"`````````````````````@`````````"`````````#/
M````#P````,``````````+Q`````````K`````````@`````````````````
M```(``````````@`````````VP````8````#``````````B\0```````"*P`
M`````````@````````<`````````"``````````0`````````.0````!````
M`P`````````(OD````````BN````````^`$```````````````````@`````
M````"`````````#I`````0````,``````````,!`````````L````````"$`
M```````````````````(````````````````````[P````@````#````````
M`$#`0```````(;````````!8````````````````````(```````````````
M`````/0````!````,````````````````````"&P````````)```````````
M``````````$``````````0`````````!`````P``````````````````````
J``!%L````````/T````````````````````!````````````````````
